#
# spec file for package perl-CPAN-Changes
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name CPAN-Changes
Name:           perl-CPAN-Changes
Version:        0.500004
Release:        1.2
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Parser for CPAN style change logs
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/H/HA/HAARG/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Module::Runtime)
BuildRequires:  perl(Moo) >= 1.006000
BuildRequires:  perl(Sub::Quote) >= 1.005000
BuildRequires:  perl(Test::More) >= 0.96
BuildRequires:  perl(Types::Standard)
Requires:       perl(Module::Runtime)
Requires:       perl(Moo) >= 1.006000
Requires:       perl(Sub::Quote) >= 1.005000
Requires:       perl(Types::Standard)
%{perl_requires}

%description
It is standard practice to include a Changes file in your distribution. The
purpose the Changes file is to help a user figure out what has changed
since the last release.

People have devised many ways to write the Changes file. A preliminary
specification has been created (CPAN::Changes::Spec) to encourage module
authors to write clear and concise Changes.

This module will help users programmatically read and write Changes files
that conform to the specification.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Fri May  3 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.500004
  see /usr/share/doc/packages/perl-CPAN-Changes/Changes
  0.500004 - 2024-05-02
  - fix tests on Windows
* Fri Feb 23 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.500003
  see /usr/share/doc/packages/perl-CPAN-Changes/Changes
  0.500003 - 2024-02-22
  - fix calling ->name on an unnamed group
  - fix ->set_changes call on groups
* Fri Oct 27 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.500002
  see /usr/share/doc/packages/perl-CPAN-Changes/Changes
  0.500002 - 2023-10-26
  - releasing as stable
  0.500_001 - 2023-08-27
  - Full rewrite. The new version can parse nested entries to an arbitrary
    depth, rather than just groups. It can parse many more formats, and can
    format the outputs more flexibly. This means it can better handle the
    change logs that actually exist on CPAN.
  - parsed releases keep their original order
  - Pass given ChangeLog filename for --check (Tux)
* Thu Jul 20 2017 coolo@suse.com
- disable perl(version) - obsolete by perl
* Mon Jun 22 2015 coolo@suse.com
- updated to 0.400002
  see /usr/share/doc/packages/perl-CPAN-Changes/Changes
  0.400002 - 2015-06-21
  - revert whitespace changes that were inadvertantly included in previous
    release.
  - escape curly brackets in test to avoid warning in perl 5.22
* Sun Jun  7 2015 coolo@suse.com
- updated to 0.400001
  see /usr/share/doc/packages/perl-CPAN-Changes/Changes
  0.400001 - 2015-05-23
  - accept either UTF-8 or ISO-8859-1 files and decode them
  - only treat bracketed text if it is on its own line with no other brackets
  - bump version.pm prereq to make sure it works properly
  - Let long tokens (like URLs) overflow rather than splitting them into
    multiple likes
  - Don't wrap on non-breaking spaces
  - Clean up packaging
  - Return undef for dates or notes that don't exist
  - Quote meta chars to fix a problem that clobbered dates
    with timezones due to the '+' char (GH #20)
* Thu Apr 16 2015 coolo@suse.com
- updated to 0.30
  see /usr/share/doc/packages/perl-CPAN-Changes/Changes
  0.30 2014-07-26
  - Fix for subclassing CPAN::Changes::Group (GH #23)
  0.29 2014-07-23
  - Groups are now objects (CPAN::Changes::Group). Backwards
    compatibility from hashes should be preserved (GH #22)
  0.28 2014-06-10
  - Add "SEE ALSO" links to similar modules (RT #94636)
  - Use perl 5.8-compatible regex
  0.27 2013-12-13
    [ Spec Changes ]
  - Bump version to 0.04
  - Allow non-"word" characters between a Version and a Date
  0.26 2013-11-21
  - Fix reference issues when adding a release (RT #90605)
  0.25 2013-10-08
  - Move Text::Wrap usage to proper module (Michal Spacek)
  - Typo fix (Karen Etheridge)
  0.24 2013-10-07
  - Fix Dist::Zilla date parsing. Now puts timezone data in
    note section (Github #17)
* Tue Oct  1 2013 coolo@suse.com
- initial package 0.23
  * created by cpanspec 1.78.07
